"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const index_1 = require("../utils/index");
function default_1(options) {
    if (!options.directory) {
        options.directory = options.name;
    }
    const templateSource = schematics_1.apply(schematics_1.url('../application/files'), [
        schematics_1.move(options.directory),
    ]);
    return schematics_1.chain([
        schematics_1.externalSchematic('@schematics/angular', 'ng-new', options),
        (tree => {
            tree.rename(`${options.directory}/src/main.ts`, `${options.directory}/src/main.browser.ts`);
            return tree;
        }),
        schematics_1.mergeWith(templateSource, schematics_1.MergeStrategy.Overwrite),
        index_1.createGitIgnore(options.directory),
        adjustCLIConfig(options),
        updatePackageJson(options)
    ]);
}
exports.default = default_1;
function updatePackageJson(options) {
    return tree => {
        let packageJsonContent = index_1.getSource(tree, `${options.directory}/package.json`);
        packageJsonContent = packageJsonContent.replace('__projectName__', options.name);
        index_1.createOrOverwriteFile(tree, `${options.directory}/package.json`, packageJsonContent);
        return tree;
    };
}
function adjustCLIConfig(options) {
    return tree => {
        const cliConfig = JSON.parse(index_1.getSource(tree, `${options.directory}/angular.json`));
        cliConfig.projects[options.name].architect.build.options.outputPath = 'dist/browser';
        cliConfig.projects[options.name].architect.build.options.main = 'src/main.browser.ts';
        cliConfig.projects[options.name].architect.build.options.assets.push({ glob: "manifest.json", input: "src", output: "/" });
        cliConfig.projects[options.name].architect.build.options.styles = [{ input: "src/styles/main.scss" }];
        cliConfig.projects[options.name].architect.build.configurations.production.serviceWorker = true;
        cliConfig.projects[options.name].architect.serve.configurations.dev = { browserTarget: `${options.name}:build:dev` };
        cliConfig.projects[options.name].architect.test.options.assets.push({ glob: "manifest.json", input: "src", output: "/" });
        cliConfig.projects[options.name].architect.test.options.styles = [{ input: "src/styles/main.scss" }];
        cliConfig.projects[options.name].architect.server = {
            builder: '@angular-devkit/build-angular:server',
            options: {
                outputPath: 'dist/server',
                main: 'src/main.server.ts',
                tsConfig: 'src/tsconfig.server.json'
            }
        };
        cliConfig.projects[`${options.name}-e2e`].architect.e2e.options.devServerTarget = `${options.name}:serve`;
        index_1.createOrOverwriteFile(tree, `${options.directory}/angular.json`, JSON.stringify(cliConfig, null, "  "));
        return tree;
    };
}
//# sourceMappingURL=index.js.map